==> zio-aws-appflow_2.13-5.17.205.1-sources.jar: zio/aws/appflow/model/GoogleAnalyticsMetadata.scala <==
package zio.aws.appflow.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.appflow.model.primitives.OAuthScope
import scala.jdk.CollectionConverters._
final case class GoogleAnalyticsMetadata(
    oAuthScopes: Optional[Iterable[OAuthScope]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.appflow.model.GoogleAnalyticsMetadata = {
    import GoogleAnalyticsMetadata.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appflow.model.GoogleAnalyticsMetadata
      .builder()
      .optionallyWith(
        oAuthScopes.map(value =>
          value.map { item =>
            OAuthScope.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.oAuthScopes)
      .build()
  }
  def asReadOnly: zio.aws.appflow.model.GoogleAnalyticsMetadata.ReadOnly =
    zio.aws.appflow.model.GoogleAnalyticsMetadata.wrap(buildAwsValue())
}
object GoogleAnalyticsMetadata {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.appflow.model.GoogleAnalyticsMetadata
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appflow.model.GoogleAnalyticsMetadata =
      zio.aws.appflow.model
        .GoogleAnalyticsMetadata(oAuthScopes.map(value => value))
    def oAuthScopes: Optional[List[OAuthScope]]
    def getOAuthScopes: ZIO[Any, AwsError, List[OAuthScope]] =
      AwsError.unwrapOptionField("oAuthScopes", oAuthScopes)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appflow.model.GoogleAnalyticsMetadata
  ) extends zio.aws.appflow.model.GoogleAnalyticsMetadata.ReadOnly {
    override val oAuthScopes: Optional[List[OAuthScope]] = zio.aws.core.internal
      .optionalFromNullable(impl.oAuthScopes())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.appflow.model.primitives.OAuthScope(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.appflow.model.GoogleAnalyticsMetadata
  ): zio.aws.appflow.model.GoogleAnalyticsMetadata.ReadOnly = new Wrapper(impl)
}

==> zio-aws-appflow_3-5.17.203.2-sources.jar: zio/aws/appflow/model/GoogleAnalyticsMetadata.scala <==
package zio.aws.appflow.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.appflow.model.primitives.OAuthScope
import scala.jdk.CollectionConverters.*
final case class GoogleAnalyticsMetadata(
    oAuthScopes: Optional[Iterable[OAuthScope]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.appflow.model.GoogleAnalyticsMetadata = {
    import GoogleAnalyticsMetadata.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appflow.model.GoogleAnalyticsMetadata
      .builder()
      .optionallyWith(
        oAuthScopes.map(value =>
          value.map { item =>
            OAuthScope.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.oAuthScopes)
      .build()
  }
  def asReadOnly: zio.aws.appflow.model.GoogleAnalyticsMetadata.ReadOnly =
    zio.aws.appflow.model.GoogleAnalyticsMetadata.wrap(buildAwsValue())
}
object GoogleAnalyticsMetadata {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.appflow.model.GoogleAnalyticsMetadata
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appflow.model.GoogleAnalyticsMetadata =
      zio.aws.appflow.model
        .GoogleAnalyticsMetadata(oAuthScopes.map(value => value))
    def oAuthScopes: Optional[List[OAuthScope]]
    def getOAuthScopes: ZIO[Any, AwsError, List[OAuthScope]] =
      AwsError.unwrapOptionField("oAuthScopes", oAuthScopes)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appflow.model.GoogleAnalyticsMetadata
  ) extends zio.aws.appflow.model.GoogleAnalyticsMetadata.ReadOnly {
    override val oAuthScopes: Optional[List[OAuthScope]] = zio.aws.core.internal
      .optionalFromNullable(impl.oAuthScopes())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.appflow.model.primitives.OAuthScope(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.appflow.model.GoogleAnalyticsMetadata
  ): zio.aws.appflow.model.GoogleAnalyticsMetadata.ReadOnly = new Wrapper(impl)
}
